pub fn black_box<T>(dummy: T) -> TExpand description
Force the compiler to avoid optimizing away a value that is computed for benchmarking purposes, but not used afterwards.
pub fn black_box<T>(dummy: T) -> TForce the compiler to avoid optimizing away a value that is computed for benchmarking purposes, but not used afterwards.